==> liveqa-1.0.0.tgz: package/distribution/api_resource.js <==
'use strict';

var _stringify = require('babel-runtime/core-js/json/stringify');

var _stringify2 = _interopRequireDefault(_stringify);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var fetch = require('isomorphic-fetch');

var ApiResource = function () {
  function ApiResource() {
    (0, _classCallCheck3.default)(this, ApiResource);
  }

  (0, _createClass3.default)(ApiResource, null, [{
    key: 'post',
    value: function post(config, resourcePath) {
      var payload = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};

      this._config = config;

      if (!this._config.API_KEY || this._config.API_KEY === '') {
        throw new Error('API_KEY is not set. Please set your api key: LiveQA.API_KEY = \'xxxx\'');
      }

      return this.request('post', resourcePath, payload);
    }
  }, {
    key: 'request',
    value: function request(method, resourcePath) {
      var payload = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};

      var url = this._config.HOST + '/api/' + this._config.API_VERSION + '/' + resourcePath;

      var requestOptions = {
        method: 'POST',
        body: (0, _stringify2.default)(payload),
        mode: 'cors',
        headers: new Headers({
          'Access-Control-Allow-Origin': '*',
          'Content-Type': 'application/json',
          Accept: 'application/json',
          'X-Request-Key': this._config.API_KEY
        })
      };

      this._send(url, requestOptions);
    }

    // private

  }, {
    key: '_send',
    value: function _send(url, options) {
      return fetch(url, options).then(function (response) {
        switch (response.status) {
          case 400:
            throw new Error('Bad response from server');
          case 401:
            throw new Error('Unauthorized, please check your api key');
          case 404:
            throw new Error('Requested Resource not found');
          case 408:
            throw new Error('Server timeout, verify status of the server');
          case 444:
            throw new Error('Server Error, please check with LiveQA');
          case 449:
            throw new Error('Server Error, please check with LiveQA');
          case 501:
            throw new Error('Server Error, please check with LiveQA');
          default:
            return response;
        }
      }).then(function (response) {
        return response;
      }).catch(function () {
        throw new Error('Server Error, please check with LiveQA');
      });
    }
  }, {
    key: '_config',
    set: function set(value) {
      this.configuration = value;
    },
    get: function get() {
      return this.configuration;
    }
  }]);
  return ApiResource;
}();

module.exports = ApiResource;

==> liveqa-1.1.1.tgz: package/distribution/api_resource.js <==
'use strict';

var _stringify = require('babel-runtime/core-js/json/stringify');

var _stringify2 = _interopRequireDefault(_stringify);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var fetch = require('isomorphic-fetch');
var Util = require('./util.js');

var ApiResource = function () {
  function ApiResource() {
    (0, _classCallCheck3.default)(this, ApiResource);
  }

  (0, _createClass3.default)(ApiResource, null, [{
    key: 'post',
    value: function post(config, resourcePath) {
      var payload = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};

      this._config = config;

      if (!this._config.apiKey || this._config.apiKey === '') {
        throw new Error('apiKey is not set. Please set your api key: LiveQA.apiKey = \'xxxx\'');
      }

      return this.request('post', resourcePath, payload);
    }
  }, {
    key: 'request',
    value: function request(method, resourcePath) {
      var payload = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};

      var cleanPayload = Util.deepObfuscateValue(payload, this._config.obfuscatedFields);
      var url = this._config.host + '/api/' + this._config.apiVersion + '/' + resourcePath;

      var requestOptions = {
        method: 'POST',
        body: (0, _stringify2.default)(cleanPayload),
        mode: 'cors',
        headers: new Headers({
          'Access-Control-Allow-Origin': '*',
          'Content-Type': 'application/json',
          Accept: 'application/json',
          'X-Request-Key': this._config.apiKey
        })
      };

      this._send(url, requestOptions);
    }

    // private

  }, {
    key: '_send',
    value: function _send(url, options) {
      return fetch(url, options).then(function (response) {
        switch (response.status) {
          case 400:
            throw new Error('Bad response from server');
          case 401:
            throw new Error('Unauthorized, please check your api key');
          case 404:
            throw new Error('Requested Resource not found');
          case 408:
            throw new Error('Server timeout, verify status of the server');
          case 444:
            throw new Error('Server Error, please check with LiveQA');
          case 449:
            throw new Error('Server Error, please check with LiveQA');
          case 501:
            throw new Error('Server Error, please check with LiveQA');
          default:
            return response;
        }
      }).then(function (response) {
        return response;
      }).catch(function () {
        throw new Error('Server Error, please check with LiveQA');
      });
    }
  }, {
    key: '_config',
    set: function set(value) {
      this.configuration = value;
    },
    get: function get() {
      return this.configuration;
    }
  }]);
  return ApiResource;
}();

module.exports = ApiResource;
